@@ -94,7 +94,7 @@ option 'schema_version' => is => 'ro',   isa => NonEmptySimpleStr,
    documentation        => 'Current schema version',
    default              => '0.1', format => 's';
 
-option 'unlink'         => is => 'ro',   isa => Bool, default => FALSE,
+option 'unlink'         => is => 'rwp',  isa => Bool, default => FALSE,
    documentation        => 'If true remove DDL file before creating new ones';
 
 option 'yes'            => is => 'ro',   isa => Bool, default => FALSE,
@@ -193,9 +193,7 @@ my $_create_ddl = sub {
       ( $self->dsn, $self->user, $self->password, $self->$_connect_attr );
 
    if ($self->unlink) {
-      for my $rdb (@{ $self->rdbms }) {
-         my $path = io( $schema->ddl_filename( $rdb, $version, $dir ) );
-
+      for my $path ($self->ddl_paths( $schema, $version, $dir )) {
          $path->is_file and $path->unlink;
       }
    }
@@ -306,6 +304,16 @@ sub create_schema : method { # Create databases and edit credentials
    return OK;
 }
 
+sub ddl_paths {
+   my ($self, $schema, $version, $dir) = @_; my @paths = ();
+
+   for my $rdb (@{ $self->rdbms }) {
+      push @paths, io( $schema->ddl_filename( $rdb, $version, $dir ) );
+   }
+
+   return @paths;
+}
+
 sub deploy_and_populate : method {
    my $self = shift; my $default = $self->yes;
 
@@ -535,6 +543,12 @@ Calls L<create_database> followed by L<deploy_and_populate>
 
 Called as part of the application install
 
+=head2 ddl_paths
+
+   @paths = $self->ddl_paths( $schema, $version, $dir );
+
+Returns a list of io objects for each of the DDL files
+
 =head2 deploy_file
 
 Deprecated in favour of L</populate_class>
